*-----------------------------------------------------------------------
      SUBROUTINE SWQFNM(CPARA,CFNAME)

      CHARACTER CPARA*(*),CFNAME*(*)

      PARAMETER (MAXP=3,MAXF=3)

      CHARACTER CPLIST(MAXP)*80,CFLIST(MAXF)*80,CPX*80

      EXTERNAL  LENC


      CPLIST(1)=' '
      CALL GLCGET('DUPATH',CPLIST(2))
      CALL GLCGET('DSPATH',CPLIST(3))

      CALL SWCGET(CPARA,CPX)
      LCP=LENC(CPX)
      CALL SWPGET('IWS',IWS)

      CFLIST(1)=CPX(1:LCP)//'.win'
      CFLIST(2)=CPX(1:LCP)

      CALL CFSRCH(CPLIST,MAXP,CFLIST,MAXF,CFNAME)
      END
